@@ -1,5 +1,5 @@
 /*
- * $Id: postgresql.sql,v 1.1.2.6 2006/08/18 10:22:36 pnixon Exp $
+ * $Id: postgresql.sql,v 1.1.2.7 2006/12/12 12:10:30 pnixon Exp $
  *
  * Postgresql schema for FreeRADIUS
  *
@@ -201,7 +201,7 @@ CREATE TABLE radippool (
 	FramedIPAddress		INET,
 	NASIPAddress		text NOT NULL,
 	CalledStationId		VARCHAR(64),
-	CallingStationId	text DEFAULT ''::text NOT NULL,
+	CallingStationId	text NOT NULL DEFAULT ''::text,
 	expiry_time		TIMESTAMP(0) without time zone NOT NULL,
 	username		text DEFAULT ''::text,
 	pool_key		VARCHAR(30) NOT NULL
