@@ -1,7 +1,7 @@
 /*
  * dict.c	Routines to read the dictionary file.
  *
- * Version:	$Id: dict.c,v 1.50.2.4.2.11 2006/08/22 23:02:38 aland Exp $
+ * Version:	$Id: dict.c,v 1.50.2.4.2.13 2006/11/26 19:50:14 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.11 2006/08/22 23:02:38 aland Exp $";
+static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.13 2006/11/26 19:50:14 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -255,6 +255,7 @@ static void dict_stat_add(const char *name, const struct stat *stat_buf)
 	dict_stat_t *this;
 
 	this = malloc(sizeof(*this));
+	if (!this) return;
 	memset(this, 0, sizeof(*this));
 
 	this->name = strdup(name);
@@ -545,6 +546,17 @@ int dict_addvalue(const char *namestr, const char *attrstr, int value)
 	dattr = dict_attrbyname(attrstr);
 	if (dattr) {
 		dval->attr = dattr->attr;
+
+		/*
+		 *	Octets is allowed as a work-around for the
+		 *	fact that branch_1_1 doesn't have BYTE or SHORT
+		 */
+		if ((dattr->type != PW_TYPE_INTEGER) &&
+		    (dattr->type != PW_TYPE_OCTETS)) {
+			librad_log("dict_addvalue: VALUEs can only be defined for'integer' types");
+			return -1;
+		}
+
 	} else {
 		value_fixup_t *fixup;
 		
