@@ -1,7 +1,7 @@
 /*
  * valuepair.c	Functions to handle VALUE_PAIRs
  *
- * Version:	$Id: valuepair.c,v 1.82.2.1.2.3 2006/05/03 17:40:58 aland Exp $
+ * Version:	$Id: valuepair.c,v 1.82.2.1.2.4 2006/11/26 19:54:00 aland Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1.2.3 2006/05/03 17:40:58 aland Exp $";
+static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1.2.4 2006/11/26 19:54:00 aland Exp $";
 
 #include	"autoconf.h"
 
@@ -706,7 +706,7 @@ VALUE_PAIR *pairparsevalue(VALUE_PAIR *vp, const char *value)
 			 *
 			 *	Note that ALL integers are unsigned!
 			 */
-			if (isdigit((int) *value)) {
+			if (strspn(value, "0123456789") == strlen(value)) {
 				vp->lvalue = (uint32_t) strtoul(value, NULL, 10);
 				vp->length = 4;
 			}
