@@ -1,7 +1,7 @@
 /*
  * rlm_eap_tls.c  contains the interfaces that are called from eap
  *
- * Version:     $Id: rlm_eap_tls.c,v 1.21.4.10 2006/08/22 16:20:41 aland Exp $
+ * Version:     $Id: rlm_eap_tls.c,v 1.21.4.12 2006/11/29 22:59:48 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -367,8 +367,13 @@ static SSL_CTX *init_tls_ctx(EAP_TLS_CONF *conf)
 	 *	SSL_OP_SINGLE_DH_USE has an impact on the computer
 	 *	time needed during negotiation, but it is not very
 	 *	large.
+	 *	 
+	 *	SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS to work around issues
+	 *	in Windows Vista client.
+	 *	http://www.openssl.org/~bodo/tls-cbc.txt
+	 *	http://www.nabble.com/(RADIATOR)-Radiator-Version-3.16-released-t2600070.html
 	 */
-   	ctx_options |= SSL_OP_SINGLE_DH_USE;
+   	ctx_options |= SSL_OP_SINGLE_DH_USE | SSL_OP_DONT_INSERT_EMPTY_FRAGMENTS;
 	SSL_CTX_set_options(ctx, ctx_options);
 
 	/*
@@ -457,7 +462,6 @@ static int eaptls_detach(void *arg)
 		free(conf->ca_file);
 		free(conf->random_file);
 
-		free(conf->check_cert_cn);
 		free(conf->check_cert_cn);
 		free(conf->cipher_list);
 		free(conf->check_cert_issuer);
